@@ -39,8 +39,8 @@ bool Copy::copyItem(const PimItem &item, const Collection &target)
     PimItem newItem = item;
     newItem.setId(-1);
     newItem.setRev(0);
-    newItem.setDatetime(QDateTime::currentDateTime());
-    newItem.setAtime(QDateTime::currentDateTime());
+    newItem.setDatetime(QDateTime::currentDateTimeUtc());
+    newItem.setAtime(QDateTime::currentDateTimeUtc());
     newItem.setRemoteId(QString());
     newItem.setRemoteRevision(QString());
     newItem.setCollectionId(target.id());
@@ -48,13 +48,14 @@ bool Copy::copyItem(const PimItem &item, const Collection &target)
     parts.reserve(item.parts().count());
     Q_FOREACH (const Part &part, item.parts()) {
         Part newPart(part);
-        newPart.setData(PartHelper::translateData(newPart.data(), part.external()));
+        newPart.setData(PartHelper::translateData(newPart.data(), part.storage()));
         newPart.setPimItemId(-1);
+        newPart.setStorage(Part::Internal);
         parts << newPart;
     }
 
     DataStore *store = connection()->storageBackend();
-    if (!store->appendPimItem(parts, item.flags(), item.mimeType(), target, QDateTime::currentDateTime(), QString(), QString(), item.gid(), newItem)) {
+    if (!store->appendPimItem(parts, item.flags(), item.mimeType(), target, QDateTime::currentDateTimeUtc(), QString(), QString(), item.gid(), newItem)) {
         return false;
     }
 
@@ -90,7 +91,7 @@ void Copy::itemsRetrieved(const QList<qint64> &ids)
 
 bool Copy::parseStream()
 {
-    Protocol::CopyItemsCommand cmd(m_command);
+    const auto &cmd = Protocol::cmdCast<Protocol::CopyItemsCommand>(m_command);
 
     if (!checkScopeConstraints(cmd.items(), Scope::Uid)) {
         return failureResponse("Only UID copy is allowed");
